Function estimates incidence from smoothed data
deconv_ww_inc(d, fec, scaling.factor, silent, RL.max.iter)Data frame with deconvoluted incidence
Data frame. Wastewater dataframe. Must include at least date, time t and
obs columns.
List. Parameters for a single fecal shedding distribution, as generated by sample_a_dist().
Numeric. Scaling from wastewater concentration to prevalence. This value may be assumed or independently calibrated to data.
Logical. Flag to suppress all output messages, warnings, and progress bars.
Integer. Maximum of iterations for the Richardson-Lucy deconvolution algorithm.