Estimate Rt using EpiEstim
incidence_to_R(incidence, generation.interval, prm.R)Data frame. Estimated incidence. Must include at least
date, I, and t columns.
List. Parameters for a single generation interval distribution, as generated by sample_a_dist().
List. Settings for the ensemble when calculating Rt. Elements include:
iter: Integer. Number of iterations for the Rt ensemble
CI: Numeric between 0 and 1. Confidence interval width for Rt
estimates after sampling uncertain distributions.
window: Integer. Number of days defining the window of data used by
EpiEstim to estimate Rt. If NULL, will default to 7.
config.EpiEstim: (optional) configuration for EpiEstim defined via
EpiEstim::make_config(). If NULL, will use default config from
EpiEstim.
def_dist()
EpiEstim::make_config()